@@ -96,7 +96,14 @@ esac
 
 
 # 0. Check if partition is a FAT partition
-if [ -z "$(parted -s $target_part print | grep -iE "(fat16|fat32|vfat)")" ]; then
+# parted -s /dev/hda1 print
+# Disk /dev/hda1: 8590MB
+# Sector size (logical/physical): 512B/512B
+# Partition Table: loop
+# 
+# Number  Start   End     Size    File system  Flags
+#  1      0.00kB  8590MB  8590MB  fat32           
+if [ -z "$(parted -s $target_disk print | grep -E "^[[:space:]]*${pt_dev_no}\>" |  grep -iE "(fat16|fat32|vfat)")" ]; then
   [ "$BOOTUP" = "color" ] && $SETCOLOR_FAILURE
   echo "$target_part: this doesn't look like a valid FAT filesystem"
   [ "$BOOTUP" = "color" ] && $SETCOLOR_NORMAL
@@ -132,6 +139,7 @@ if [ "$bootable" != "*" ]; then
        exit 1
        ;;
   esac
+  echo "Running: parted -s $target_disk set $pt_dev_no boot on"
   parted -s $target_disk set $pt_dev_no boot on
 fi
 
@@ -162,5 +170,11 @@ case "$make_syslinux_ans" in
      exit 1
      ;;
 esac
-echo "Running: ./syslinux -fs $target_part"
-./syslinux -fs $target_part
+# Since most of the cases when makeboot.sh is run, all the files are in FAT (USB flash drive normally uses FAT), we have to make syslinux executable.
+echo "We need a filesystem supporting Unix file mode for syslinux. Copying syslinux from FAT to /tmp/..."
+syslinux_tmpd="$(mktemp -d /tmp/syslinux.XXXXXX)"
+cp -fv syslinux $syslinux_tmpd
+chmod u+x $syslinux_tmpd/syslinux
+echo "Running: $syslinux_tmpd/syslinux -fs $target_part"
+$syslinux_tmpd/syslinux -fs $target_part
+[ -d "$syslinux_tmpd" -a -n "$syslinux_tmpd" ] && rm -rf $syslinux_tmpd
